# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InvitationArgs', 'Invitation']

@pulumi.input_type
class InvitationArgs:
    def __init__(__self__, *,
                 redirect_url: pulumi.Input[str],
                 user_email_address: pulumi.Input[str],
                 message: Optional[pulumi.Input['InvitationMessageArgs']] = None,
                 user_display_name: Optional[pulumi.Input[str]] = None,
                 user_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Invitation resource.
        :param pulumi.Input[str] redirect_url: The URL that the user should be redirected to once the invitation is redeemed.
        :param pulumi.Input[str] user_email_address: The email address of the user being invited.
        :param pulumi.Input['InvitationMessageArgs'] message: A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        :param pulumi.Input[str] user_display_name: The display name of the user being invited.
        :param pulumi.Input[str] user_type: The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        pulumi.set(__self__, "redirect_url", redirect_url)
        pulumi.set(__self__, "user_email_address", user_email_address)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if user_display_name is not None:
            pulumi.set(__self__, "user_display_name", user_display_name)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @property
    @pulumi.getter(name="redirectUrl")
    def redirect_url(self) -> pulumi.Input[str]:
        """
        The URL that the user should be redirected to once the invitation is redeemed.
        """
        return pulumi.get(self, "redirect_url")

    @redirect_url.setter
    def redirect_url(self, value: pulumi.Input[str]):
        pulumi.set(self, "redirect_url", value)

    @property
    @pulumi.getter(name="userEmailAddress")
    def user_email_address(self) -> pulumi.Input[str]:
        """
        The email address of the user being invited.
        """
        return pulumi.get(self, "user_email_address")

    @user_email_address.setter
    def user_email_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_email_address", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input['InvitationMessageArgs']]:
        """
        A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input['InvitationMessageArgs']]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="userDisplayName")
    def user_display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the user being invited.
        """
        return pulumi.get(self, "user_display_name")

    @user_display_name.setter
    def user_display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_display_name", value)

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[str]]:
        """
        The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_type", value)


@pulumi.input_type
class _InvitationState:
    def __init__(__self__, *,
                 message: Optional[pulumi.Input['InvitationMessageArgs']] = None,
                 redeem_url: Optional[pulumi.Input[str]] = None,
                 redirect_url: Optional[pulumi.Input[str]] = None,
                 user_display_name: Optional[pulumi.Input[str]] = None,
                 user_email_address: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 user_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Invitation resources.
        :param pulumi.Input['InvitationMessageArgs'] message: A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        :param pulumi.Input[str] redeem_url: The URL the user can use to redeem their invitation.
        :param pulumi.Input[str] redirect_url: The URL that the user should be redirected to once the invitation is redeemed.
        :param pulumi.Input[str] user_display_name: The display name of the user being invited.
        :param pulumi.Input[str] user_email_address: The email address of the user being invited.
        :param pulumi.Input[str] user_id: Object ID of the invited user.
        :param pulumi.Input[str] user_type: The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        if message is not None:
            pulumi.set(__self__, "message", message)
        if redeem_url is not None:
            pulumi.set(__self__, "redeem_url", redeem_url)
        if redirect_url is not None:
            pulumi.set(__self__, "redirect_url", redirect_url)
        if user_display_name is not None:
            pulumi.set(__self__, "user_display_name", user_display_name)
        if user_email_address is not None:
            pulumi.set(__self__, "user_email_address", user_email_address)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input['InvitationMessageArgs']]:
        """
        A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input['InvitationMessageArgs']]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="redeemUrl")
    def redeem_url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL the user can use to redeem their invitation.
        """
        return pulumi.get(self, "redeem_url")

    @redeem_url.setter
    def redeem_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redeem_url", value)

    @property
    @pulumi.getter(name="redirectUrl")
    def redirect_url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL that the user should be redirected to once the invitation is redeemed.
        """
        return pulumi.get(self, "redirect_url")

    @redirect_url.setter
    def redirect_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redirect_url", value)

    @property
    @pulumi.getter(name="userDisplayName")
    def user_display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the user being invited.
        """
        return pulumi.get(self, "user_display_name")

    @user_display_name.setter
    def user_display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_display_name", value)

    @property
    @pulumi.getter(name="userEmailAddress")
    def user_email_address(self) -> Optional[pulumi.Input[str]]:
        """
        The email address of the user being invited.
        """
        return pulumi.get(self, "user_email_address")

    @user_email_address.setter
    def user_email_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_email_address", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        Object ID of the invited user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[str]]:
        """
        The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_type", value)


class Invitation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 message: Optional[pulumi.Input[pulumi.InputType['InvitationMessageArgs']]] = None,
                 redirect_url: Optional[pulumi.Input[str]] = None,
                 user_display_name: Optional[pulumi.Input[str]] = None,
                 user_email_address: Optional[pulumi.Input[str]] = None,
                 user_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an invitation of a guest user within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires one of the following application roles: `User.Invite.All`, `User.ReadWrite.All` or `Directory.ReadWrite.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Guest Inviter`, `User Administrator` or `Global Administrator`

        ## Example Usage

        *Basic example*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            redirect_url="https://portal.azure.com",
            user_email_address="jdoe@hashicorp.com")
        ```

        *Invitation with standard message*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            message=azuread.InvitationMessageArgs(
                language="en-US",
            ),
            redirect_url="https://portal.azure.com",
            user_email_address="jdoe@hashicorp.com")
        ```

        *Invitation with custom message body and an additional recipient*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            message=azuread.InvitationMessageArgs(
                additional_recipients="aaliceberg@hashicorp.com",
                body="Hello there! You are invited to join my Azure tenant!",
            ),
            redirect_url="https://portal.azure.com",
            user_display_name="Bob Bobson",
            user_email_address="bbobson@hashicorp.com")
        ```

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['InvitationMessageArgs']] message: A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        :param pulumi.Input[str] redirect_url: The URL that the user should be redirected to once the invitation is redeemed.
        :param pulumi.Input[str] user_display_name: The display name of the user being invited.
        :param pulumi.Input[str] user_email_address: The email address of the user being invited.
        :param pulumi.Input[str] user_type: The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InvitationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an invitation of a guest user within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires one of the following application roles: `User.Invite.All`, `User.ReadWrite.All` or `Directory.ReadWrite.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Guest Inviter`, `User Administrator` or `Global Administrator`

        ## Example Usage

        *Basic example*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            redirect_url="https://portal.azure.com",
            user_email_address="jdoe@hashicorp.com")
        ```

        *Invitation with standard message*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            message=azuread.InvitationMessageArgs(
                language="en-US",
            ),
            redirect_url="https://portal.azure.com",
            user_email_address="jdoe@hashicorp.com")
        ```

        *Invitation with custom message body and an additional recipient*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Invitation("example",
            message=azuread.InvitationMessageArgs(
                additional_recipients="aaliceberg@hashicorp.com",
                body="Hello there! You are invited to join my Azure tenant!",
            ),
            redirect_url="https://portal.azure.com",
            user_display_name="Bob Bobson",
            user_email_address="bbobson@hashicorp.com")
        ```

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param InvitationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InvitationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 message: Optional[pulumi.Input[pulumi.InputType['InvitationMessageArgs']]] = None,
                 redirect_url: Optional[pulumi.Input[str]] = None,
                 user_display_name: Optional[pulumi.Input[str]] = None,
                 user_email_address: Optional[pulumi.Input[str]] = None,
                 user_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InvitationArgs.__new__(InvitationArgs)

            __props__.__dict__["message"] = message
            if redirect_url is None and not opts.urn:
                raise TypeError("Missing required property 'redirect_url'")
            __props__.__dict__["redirect_url"] = redirect_url
            __props__.__dict__["user_display_name"] = user_display_name
            if user_email_address is None and not opts.urn:
                raise TypeError("Missing required property 'user_email_address'")
            __props__.__dict__["user_email_address"] = user_email_address
            __props__.__dict__["user_type"] = user_type
            __props__.__dict__["redeem_url"] = None
            __props__.__dict__["user_id"] = None
        super(Invitation, __self__).__init__(
            'azuread:index/invitation:Invitation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            message: Optional[pulumi.Input[pulumi.InputType['InvitationMessageArgs']]] = None,
            redeem_url: Optional[pulumi.Input[str]] = None,
            redirect_url: Optional[pulumi.Input[str]] = None,
            user_display_name: Optional[pulumi.Input[str]] = None,
            user_email_address: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None,
            user_type: Optional[pulumi.Input[str]] = None) -> 'Invitation':
        """
        Get an existing Invitation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['InvitationMessageArgs']] message: A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        :param pulumi.Input[str] redeem_url: The URL the user can use to redeem their invitation.
        :param pulumi.Input[str] redirect_url: The URL that the user should be redirected to once the invitation is redeemed.
        :param pulumi.Input[str] user_display_name: The display name of the user being invited.
        :param pulumi.Input[str] user_email_address: The email address of the user being invited.
        :param pulumi.Input[str] user_id: Object ID of the invited user.
        :param pulumi.Input[str] user_type: The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InvitationState.__new__(_InvitationState)

        __props__.__dict__["message"] = message
        __props__.__dict__["redeem_url"] = redeem_url
        __props__.__dict__["redirect_url"] = redirect_url
        __props__.__dict__["user_display_name"] = user_display_name
        __props__.__dict__["user_email_address"] = user_email_address
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["user_type"] = user_type
        return Invitation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def message(self) -> pulumi.Output[Optional['outputs.InvitationMessage']]:
        """
        A `message` block as documented below, which configures the message being sent to the invited user. If this block is omitted, no message will be sent.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter(name="redeemUrl")
    def redeem_url(self) -> pulumi.Output[str]:
        """
        The URL the user can use to redeem their invitation.
        """
        return pulumi.get(self, "redeem_url")

    @property
    @pulumi.getter(name="redirectUrl")
    def redirect_url(self) -> pulumi.Output[str]:
        """
        The URL that the user should be redirected to once the invitation is redeemed.
        """
        return pulumi.get(self, "redirect_url")

    @property
    @pulumi.getter(name="userDisplayName")
    def user_display_name(self) -> pulumi.Output[Optional[str]]:
        """
        The display name of the user being invited.
        """
        return pulumi.get(self, "user_display_name")

    @property
    @pulumi.getter(name="userEmailAddress")
    def user_email_address(self) -> pulumi.Output[str]:
        """
        The email address of the user being invited.
        """
        return pulumi.get(self, "user_email_address")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        Object ID of the invited user.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userType")
    def user_type(self) -> pulumi.Output[Optional[str]]:
        """
        The user type of the user being invited. Must be one of `Guest` or `Member`. Only Global Administrators can invite users as members. Defaults to `Guest`.
        """
        return pulumi.get(self, "user_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NamedLocationArgs', 'NamedLocation']

@pulumi.input_type
class NamedLocationArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[str],
                 country: Optional[pulumi.Input['NamedLocationCountryArgs']] = None,
                 ip: Optional[pulumi.Input['NamedLocationIpArgs']] = None):
        """
        The set of arguments for constructing a NamedLocation resource.
        :param pulumi.Input[str] display_name: The friendly name for this named location.
        :param pulumi.Input['NamedLocationCountryArgs'] country: A `country` block as documented below, which configures a country-based named location.
        :param pulumi.Input['NamedLocationIpArgs'] ip: An `ip` block as documented below, which configures an IP-based named location.
        """
        pulumi.set(__self__, "display_name", display_name)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        The friendly name for this named location.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input['NamedLocationCountryArgs']]:
        """
        A `country` block as documented below, which configures a country-based named location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input['NamedLocationCountryArgs']]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input['NamedLocationIpArgs']]:
        """
        An `ip` block as documented below, which configures an IP-based named location.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input['NamedLocationIpArgs']]):
        pulumi.set(self, "ip", value)


@pulumi.input_type
class _NamedLocationState:
    def __init__(__self__, *,
                 country: Optional[pulumi.Input['NamedLocationCountryArgs']] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input['NamedLocationIpArgs']] = None):
        """
        Input properties used for looking up and filtering NamedLocation resources.
        :param pulumi.Input['NamedLocationCountryArgs'] country: A `country` block as documented below, which configures a country-based named location.
        :param pulumi.Input[str] display_name: The friendly name for this named location.
        :param pulumi.Input['NamedLocationIpArgs'] ip: An `ip` block as documented below, which configures an IP-based named location.
        """
        if country is not None:
            pulumi.set(__self__, "country", country)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input['NamedLocationCountryArgs']]:
        """
        A `country` block as documented below, which configures a country-based named location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input['NamedLocationCountryArgs']]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The friendly name for this named location.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input['NamedLocationIpArgs']]:
        """
        An `ip` block as documented below, which configures an IP-based named location.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input['NamedLocationIpArgs']]):
        pulumi.set(self, "ip", value)


class NamedLocation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 country: Optional[pulumi.Input[pulumi.InputType['NamedLocationCountryArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[pulumi.InputType['NamedLocationIpArgs']]] = None,
                 __props__=None):
        """
        Manages a Named Location within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example_ip = azuread.NamedLocation("example-ip",
            display_name="IP Named Location",
            ip=azuread.NamedLocationIpArgs(
                ip_ranges=[
                    "1.1.1.1/32",
                    "2.2.2.2/32",
                ],
                trusted=True,
            ))
        example_country = azuread.NamedLocation("example-country",
            country=azuread.NamedLocationCountryArgs(
                countries_and_regions=[
                    "GB",
                    "US",
                ],
                include_unknown_countries_and_regions=False,
            ),
            display_name="Country Named Location")
        ```

        ## Import

        Named Locations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import azuread:index/namedLocation:NamedLocation my_location 00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['NamedLocationCountryArgs']] country: A `country` block as documented below, which configures a country-based named location.
        :param pulumi.Input[str] display_name: The friendly name for this named location.
        :param pulumi.Input[pulumi.InputType['NamedLocationIpArgs']] ip: An `ip` block as documented below, which configures an IP-based named location.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NamedLocationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Named Location within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example_ip = azuread.NamedLocation("example-ip",
            display_name="IP Named Location",
            ip=azuread.NamedLocationIpArgs(
                ip_ranges=[
                    "1.1.1.1/32",
                    "2.2.2.2/32",
                ],
                trusted=True,
            ))
        example_country = azuread.NamedLocation("example-country",
            country=azuread.NamedLocationCountryArgs(
                countries_and_regions=[
                    "GB",
                    "US",
                ],
                include_unknown_countries_and_regions=False,
            ),
            display_name="Country Named Location")
        ```

        ## Import

        Named Locations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import azuread:index/namedLocation:NamedLocation my_location 00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param NamedLocationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NamedLocationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 country: Optional[pulumi.Input[pulumi.InputType['NamedLocationCountryArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[pulumi.InputType['NamedLocationIpArgs']]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NamedLocationArgs.__new__(NamedLocationArgs)

            __props__.__dict__["country"] = country
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["ip"] = ip
        super(NamedLocation, __self__).__init__(
            'azuread:index/namedLocation:NamedLocation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            country: Optional[pulumi.Input[pulumi.InputType['NamedLocationCountryArgs']]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            ip: Optional[pulumi.Input[pulumi.InputType['NamedLocationIpArgs']]] = None) -> 'NamedLocation':
        """
        Get an existing NamedLocation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['NamedLocationCountryArgs']] country: A `country` block as documented below, which configures a country-based named location.
        :param pulumi.Input[str] display_name: The friendly name for this named location.
        :param pulumi.Input[pulumi.InputType['NamedLocationIpArgs']] ip: An `ip` block as documented below, which configures an IP-based named location.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NamedLocationState.__new__(_NamedLocationState)

        __props__.__dict__["country"] = country
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["ip"] = ip
        return NamedLocation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def country(self) -> pulumi.Output[Optional['outputs.NamedLocationCountry']]:
        """
        A `country` block as documented below, which configures a country-based named location.
        """
        return pulumi.get(self, "country")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The friendly name for this named location.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[Optional['outputs.NamedLocationIp']]:
        """
        An `ip` block as documented below, which configures an IP-based named location.
        """
        return pulumi.get(self, "ip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConditionalAccessPolicyArgs', 'ConditionalAccessPolicy']

@pulumi.input_type
class ConditionalAccessPolicyArgs:
    def __init__(__self__, *,
                 conditions: pulumi.Input['ConditionalAccessPolicyConditionsArgs'],
                 display_name: pulumi.Input[str],
                 grant_controls: pulumi.Input['ConditionalAccessPolicyGrantControlsArgs'],
                 state: pulumi.Input[str],
                 session_controls: Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']] = None):
        """
        The set of arguments for constructing a ConditionalAccessPolicy resource.
        :param pulumi.Input['ConditionalAccessPolicyConditionsArgs'] conditions: A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        :param pulumi.Input[str] display_name: The friendly name for this Conditional Access Policy.
        :param pulumi.Input['ConditionalAccessPolicyGrantControlsArgs'] grant_controls: A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        :param pulumi.Input[str] state: Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        :param pulumi.Input['ConditionalAccessPolicySessionControlsArgs'] session_controls: A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        """
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "grant_controls", grant_controls)
        pulumi.set(__self__, "state", state)
        if session_controls is not None:
            pulumi.set(__self__, "session_controls", session_controls)

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Input['ConditionalAccessPolicyConditionsArgs']:
        """
        A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: pulumi.Input['ConditionalAccessPolicyConditionsArgs']):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        The friendly name for this Conditional Access Policy.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="grantControls")
    def grant_controls(self) -> pulumi.Input['ConditionalAccessPolicyGrantControlsArgs']:
        """
        A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        """
        return pulumi.get(self, "grant_controls")

    @grant_controls.setter
    def grant_controls(self, value: pulumi.Input['ConditionalAccessPolicyGrantControlsArgs']):
        pulumi.set(self, "grant_controls", value)

    @property
    @pulumi.getter
    def state(self) -> pulumi.Input[str]:
        """
        Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: pulumi.Input[str]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="sessionControls")
    def session_controls(self) -> Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']]:
        """
        A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        """
        return pulumi.get(self, "session_controls")

    @session_controls.setter
    def session_controls(self, value: Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']]):
        pulumi.set(self, "session_controls", value)


@pulumi.input_type
class _ConditionalAccessPolicyState:
    def __init__(__self__, *,
                 conditions: Optional[pulumi.Input['ConditionalAccessPolicyConditionsArgs']] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_controls: Optional[pulumi.Input['ConditionalAccessPolicyGrantControlsArgs']] = None,
                 session_controls: Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConditionalAccessPolicy resources.
        :param pulumi.Input['ConditionalAccessPolicyConditionsArgs'] conditions: A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        :param pulumi.Input[str] display_name: The friendly name for this Conditional Access Policy.
        :param pulumi.Input['ConditionalAccessPolicyGrantControlsArgs'] grant_controls: A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        :param pulumi.Input['ConditionalAccessPolicySessionControlsArgs'] session_controls: A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        :param pulumi.Input[str] state: Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if grant_controls is not None:
            pulumi.set(__self__, "grant_controls", grant_controls)
        if session_controls is not None:
            pulumi.set(__self__, "session_controls", session_controls)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input['ConditionalAccessPolicyConditionsArgs']]:
        """
        A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input['ConditionalAccessPolicyConditionsArgs']]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The friendly name for this Conditional Access Policy.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="grantControls")
    def grant_controls(self) -> Optional[pulumi.Input['ConditionalAccessPolicyGrantControlsArgs']]:
        """
        A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        """
        return pulumi.get(self, "grant_controls")

    @grant_controls.setter
    def grant_controls(self, value: Optional[pulumi.Input['ConditionalAccessPolicyGrantControlsArgs']]):
        pulumi.set(self, "grant_controls", value)

    @property
    @pulumi.getter(name="sessionControls")
    def session_controls(self) -> Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']]:
        """
        A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        """
        return pulumi.get(self, "session_controls")

    @session_controls.setter
    def session_controls(self, value: Optional[pulumi.Input['ConditionalAccessPolicySessionControlsArgs']]):
        pulumi.set(self, "session_controls", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class ConditionalAccessPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 conditions: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyConditionsArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyGrantControlsArgs']]] = None,
                 session_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicySessionControlsArgs']]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Conditional Access Policy within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ConditionalAccessPolicy("example",
            conditions=azuread.ConditionalAccessPolicyConditionsArgs(
                applications=azuread.ConditionalAccessPolicyConditionsApplicationsArgs(
                    excluded_applications=["00000004-0000-0ff1-ce00-000000000000"],
                    included_applications=["All"],
                ),
                client_app_types=["all"],
                locations=azuread.ConditionalAccessPolicyConditionsLocationsArgs(
                    excluded_locations=["AllTrusted"],
                    included_locations=["All"],
                ),
                platforms=azuread.ConditionalAccessPolicyConditionsPlatformsArgs(
                    excluded_platforms=["iOS"],
                    included_platforms=["android"],
                ),
                sign_in_risk_levels=["medium"],
                user_risk_levels=["medium"],
                users=azuread.ConditionalAccessPolicyConditionsUsersArgs(
                    excluded_users=["GuestsOrExternalUsers"],
                    included_users=["All"],
                ),
            ),
            display_name="example policy",
            grant_controls=azuread.ConditionalAccessPolicyGrantControlsArgs(
                built_in_controls=["mfa"],
                operator="OR",
            ),
            session_controls=azuread.ConditionalAccessPolicySessionControlsArgs(
                application_enforced_restrictions=[{
                    "enabled": True,
                }],
                cloud_app_security=[{
                    "cloudAppSecurityType": "monitorOnly",
                    "enabled": True,
                }],
                sign_in_frequency=[{
                    "enabled": True,
                    "type": "hours",
                    "value": 10,
                }],
            ),
            state="disabled")
        ```

        ## Import

        Conditional Access Policies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import azuread:index/conditionalAccessPolicy:ConditionalAccessPolicy my_location 00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicyConditionsArgs']] conditions: A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        :param pulumi.Input[str] display_name: The friendly name for this Conditional Access Policy.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicyGrantControlsArgs']] grant_controls: A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicySessionControlsArgs']] session_controls: A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        :param pulumi.Input[str] state: Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConditionalAccessPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Conditional Access Policy within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ConditionalAccessPolicy("example",
            conditions=azuread.ConditionalAccessPolicyConditionsArgs(
                applications=azuread.ConditionalAccessPolicyConditionsApplicationsArgs(
                    excluded_applications=["00000004-0000-0ff1-ce00-000000000000"],
                    included_applications=["All"],
                ),
                client_app_types=["all"],
                locations=azuread.ConditionalAccessPolicyConditionsLocationsArgs(
                    excluded_locations=["AllTrusted"],
                    included_locations=["All"],
                ),
                platforms=azuread.ConditionalAccessPolicyConditionsPlatformsArgs(
                    excluded_platforms=["iOS"],
                    included_platforms=["android"],
                ),
                sign_in_risk_levels=["medium"],
                user_risk_levels=["medium"],
                users=azuread.ConditionalAccessPolicyConditionsUsersArgs(
                    excluded_users=["GuestsOrExternalUsers"],
                    included_users=["All"],
                ),
            ),
            display_name="example policy",
            grant_controls=azuread.ConditionalAccessPolicyGrantControlsArgs(
                built_in_controls=["mfa"],
                operator="OR",
            ),
            session_controls=azuread.ConditionalAccessPolicySessionControlsArgs(
                application_enforced_restrictions=[{
                    "enabled": True,
                }],
                cloud_app_security=[{
                    "cloudAppSecurityType": "monitorOnly",
                    "enabled": True,
                }],
                sign_in_frequency=[{
                    "enabled": True,
                    "type": "hours",
                    "value": 10,
                }],
            ),
            state="disabled")
        ```

        ## Import

        Conditional Access Policies can be imported using the `id`, e.g.

        ```sh
         $ pulumi import azuread:index/conditionalAccessPolicy:ConditionalAccessPolicy my_location 00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param ConditionalAccessPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConditionalAccessPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 conditions: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyConditionsArgs']]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyGrantControlsArgs']]] = None,
                 session_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicySessionControlsArgs']]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConditionalAccessPolicyArgs.__new__(ConditionalAccessPolicyArgs)

            if conditions is None and not opts.urn:
                raise TypeError("Missing required property 'conditions'")
            __props__.__dict__["conditions"] = conditions
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if grant_controls is None and not opts.urn:
                raise TypeError("Missing required property 'grant_controls'")
            __props__.__dict__["grant_controls"] = grant_controls
            __props__.__dict__["session_controls"] = session_controls
            if state is None and not opts.urn:
                raise TypeError("Missing required property 'state'")
            __props__.__dict__["state"] = state
        super(ConditionalAccessPolicy, __self__).__init__(
            'azuread:index/conditionalAccessPolicy:ConditionalAccessPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            conditions: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyConditionsArgs']]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            grant_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicyGrantControlsArgs']]] = None,
            session_controls: Optional[pulumi.Input[pulumi.InputType['ConditionalAccessPolicySessionControlsArgs']]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'ConditionalAccessPolicy':
        """
        Get an existing ConditionalAccessPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicyConditionsArgs']] conditions: A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        :param pulumi.Input[str] display_name: The friendly name for this Conditional Access Policy.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicyGrantControlsArgs']] grant_controls: A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        :param pulumi.Input[pulumi.InputType['ConditionalAccessPolicySessionControlsArgs']] session_controls: A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        :param pulumi.Input[str] state: Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConditionalAccessPolicyState.__new__(_ConditionalAccessPolicyState)

        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["grant_controls"] = grant_controls
        __props__.__dict__["session_controls"] = session_controls
        __props__.__dict__["state"] = state
        return ConditionalAccessPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output['outputs.ConditionalAccessPolicyConditions']:
        """
        A `conditions` block as documented below, which specifies the rules that must be met for the policy to apply.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The friendly name for this Conditional Access Policy.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="grantControls")
    def grant_controls(self) -> pulumi.Output['outputs.ConditionalAccessPolicyGrantControls']:
        """
        A `grant_controls` block as documented below, which specifies the grant controls that must be fulfilled to pass the policy.
        """
        return pulumi.get(self, "grant_controls")

    @property
    @pulumi.getter(name="sessionControls")
    def session_controls(self) -> pulumi.Output[Optional['outputs.ConditionalAccessPolicySessionControls']]:
        """
        A `session_controls` block as documented below, which specifies the session controls that are enforced after sign-in.
        """
        return pulumi.get(self, "session_controls")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Specifies the state of the policy object. Possible values are: `enabled`, `disabled` and `enabledForReportingButNotEnforced`
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetClientConfigResult',
    'AwaitableGetClientConfigResult',
    'get_client_config',
]

@pulumi.output_type
class GetClientConfigResult:
    """
    A collection of values returned by getClientConfig.
    """
    def __init__(__self__, client_id=None, id=None, object_id=None, tenant_id=None):
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        pulumi.set(__self__, "object_id", object_id)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> str:
        """
        The client ID (application ID) linked to the authenticated principal, or the application used for delegated authentication.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> str:
        """
        The object ID of the authenticated principal.
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The tenant ID of the authenticated principal.
        """
        return pulumi.get(self, "tenant_id")


class AwaitableGetClientConfigResult(GetClientConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClientConfigResult(
            client_id=self.client_id,
            id=self.id,
            object_id=self.object_id,
            tenant_id=self.tenant_id)


def get_client_config(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClientConfigResult:
    """
    Use this data source to access the configuration of the AzureAD provider.

    ## API Permissions

    No additional roles are required to use this data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azuread as azuread

    current = azuread.get_client_config()
    pulumi.export("objectId", current.object_id)
    ```
    """
    __args__ = dict()
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azuread:index/getClientConfig:getClientConfig', __args__, opts=opts, typ=GetClientConfigResult).value

    return AwaitableGetClientConfigResult(
        client_id=__ret__.client_id,
        id=__ret__.id,
        object_id=__ret__.object_id,
        tenant_id=__ret__.tenant_id)
